function ns=buff(n1,n2,ntimes,k,s,b)
% function ns=buff(n1,n2,ntimes,k,s,b) model of buffalo population changes
% model of buffalo population changes
% n1 is the population in the 1st year, n2 is the population
% in the second year.  ntimes will be the vector length of ns.
% k is the harvest parameter.
% s is the survival parameter, default = .9
% b is the net bith parameter, default = .1269
if nargin<6
   b=.1269;
   if nargin<5
      s=.9;
   end
end
ns=[n1,n2];
for j=3:ntimes
    ns(j)=(s-k)*ns(j-1)+b*ns(j-2);
end
